@@ -20,7 +20,9 @@
 # OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
 # WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
-from pipcontrol import *
+# from pipcontrol import *
+from .pipcontrol import *
+
 
 __all__ = [
     "install",
